/*
Description of the basic function:
A main board is communicating with 6 slave boards over SPI. It does use an addressing byte instead of
chip select lines. All slaves are on the same bus. After receiving 6 bytes the affected slave (right address) acklowedges 
the request by puting 0xFF into TXBUF while the master is clocking out 2 times 0x81 (see picture).
(Sometimes I can see the 0xFF by the second 0x81). For that reason it turns on its SOMI pin. 
At the same time the 'gFlagRxSPI' is set and a answer is generated in the main loop. If the answer is generated 
correctly the interrupt for TX is enabled. And then the ISR is handling the next 4 bytes.

The problem now is that the ISR 'overwrites' the 0xFF in the TXBUF with the first answer byte (0x21).

*/
/***************************************************************************************************
Function name	: USCI0RX_ISR
Description		: interrupt service routine of SPI (from main controller board)
***************************************************************************************************/
#pragma vector=USCIAB0RX_VECTOR
__interrupt void USCI0RX_ISR (void)
{
	dataRxSPI = UCB0RXBUF;
	
	if(dataRxSPI != 0x81)
	{
		fillSPIArray();
	}
}


/***************************************************************************************************
Function name	: USCI0RX_ISR
Description		: interrupt service routine of SPI (from main controller board)
***************************************************************************************************/
#pragma vector=USCIAB0TX_VECTOR
__interrupt void USCI0TX_ISR (void)
{
	ON_DEBUG;																// set debug pin (green signal on scope)

	SET_SEL_SOMI_BUS;														// set SEL for SOMI pin
	
	UCB0TXBUF = gDataSPIBusTx.data[gDataSPIBusTx.index];
	gDataSPIBusTx.index++;
	if(gDataSPIBusTx.index > gDataSPIBusTx.length)
	{
		IE2 &= ~UCB0TXIE;
		gDataSPIBusTx.index = 0;
		UCB0TXBUF = 0x00;
	}

	OFF_DEBUG;																// reset debug pin (green signal on scope)
}

/***************************************************************************************************
Function name	: fillSPIArray
Description		: fills array with received data
Parameters		: none
Result			: none
***************************************************************************************************/
void fillSPIArray(void)
{
	switch(dataRxSPI)
	{	
		
		case 0x85:															// start of package
			gDataSPIBusRx.data[0] = dataRxSPI;
			gDataSPIBusRx.index = 1;
			RESET_SEL_SOMI_BUS;												// reset SEL for SOMI pin
			break;
		case 0x83:															// end of package
			if(gDataSPIBusRx.index == 5 && gDataSPIBusRx.data[1] & gCardAddress)
			{
				ON_DEBUG;													// set debug pin (green signal on scope)
				SET_SEL_SOMI_BUS;											// set SEL for SOMI pin
				UCB0TXBUF = 0xFF;
				
				gDataSPIBusRx.data[gDataSPIBusRx.index] = dataRxSPI;		// fill in last byte
				gDataSPIBusRx.length = gDataSPIBusRx.index + 1;				// set length
				gFlagRxSPI = 1;												// set flag for further processing of received data
				OFF_DEBUG;													// reset debug pin (green signal on scope)
			}
			break;
		default:
			if(gDataSPIBusRx.index < 5)
			{
				gDataSPIBusRx.data[gDataSPIBusRx.index] = dataRxSPI;
			}
			gDataSPIBusRx.index++;
			RESET_SEL_SOMI_BUS;
			break;
	}
}



/*cutout from main loop*/
if(gFlagRxSPI)
{
	if(fillRequestDataArray(gLoopAddress, gCommunicationCommand))
	{
		IE2 |= UCB0TXIE;
	}
	gFlagRxSPI = 0;
}

